#
# spec file for package dhcpcd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dhcpcd
Version:        10.2.4
Release:        1.1
Summary:        Minimal DHCPv4 and DHCPv6 client
License:        BSD-2-Clause
URL:            https://github.com/NetworkConfiguration/dhcpcd
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        dhcpcd.conf
Source4:        dhcpcd.service
Source5:        dhcpcd@.service
BuildRequires:  sysuser-tools
%sysusers_requires

%description
dhcpcd is a DHCP and a DHCPv6 client. It's also an IPv4LL (aka ZeroConf)
client. In layperson's terms, dhcpcd runs on your machine and silently
configures your computer to work on the attached networks without trouble and
mostly without configuration.

%prep
%autosetup -p1

%build
%configure \
    --dbdir=%{_sharedstatedir}/dhcpcd \
    --runstatedir=%{_rundir} \
    --privsepuser=dhcpcd
%make_build
%sysusers_generate_pre %{SOURCE3} dhcpcd dhcpcd.conf

%check
%make_build test

%install
%make_install
install -D -m 0644 %{SOURCE4} %{buildroot}%{_unitdir}/dhcpcd.service
install -D -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/dhcpcd@.service
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysusersdir}/dhcpcd.conf
install -d %{buildroot}%{_sharedstatedir}/dhcpcd

%pre -f dhcpcd.pre
%service_add_pre dhcpcd.service

%post
%service_add_post dhcpcd.service

%preun
%service_del_preun dhcpcd.service

%postun
%service_del_postun dhcpcd.service

%files
%license LICENSE
%doc README.md
%doc %{_mandir}/man5/*5*
%doc %{_mandir}/man8/*8*
%{_sbindir}/dhcpcd
%config(noreplace) %{_sysconfdir}/dhcpcd.conf
%dir %{_libexecdir}/dhcpcd-hooks
%{_libexecdir}/dhcpcd-hooks/01-test
%{_libexecdir}/dhcpcd-hooks/20-resolv.conf
%{_libexecdir}/dhcpcd-hooks/30-hostname
%{_libexecdir}/dhcpcd-run-hooks
%dir %{_datadir}/dhcpcd
%dir %{_datadir}/dhcpcd/hooks
%{_datadir}/dhcpcd/hooks/10-wpa_supplicant
%{_datadir}/dhcpcd/hooks/15-timezone
%{_datadir}/dhcpcd/hooks/29-lookup-hostname
%{_datadir}/dhcpcd/hooks/50-yp.conf
%{_unitdir}/dhcpcd.service
%{_unitdir}/dhcpcd@.service
%{_sysusersdir}/dhcpcd.conf
%attr(0750,root,root) %dir %{_sharedstatedir}/dhcpcd

%changelog
* Mon Jun  2 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.2.4
  * compat: use timingsafe_bcmp if available
  * IPv6: Sort routers by reachability correctly.
  * definitions: define ND Route Information option
  * IPv6: Clear previous address RA flags on receipt of a RA.
* Fri May 16 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.2.3
  * Restore logic on when to open an address specific socket
  * [Fix] DHCP Failure on WAN Interface Rename (Fixes #504)
  * BSD: routes via P2P interfaces now find their out-going
    interface
  * -b --background fixed
  * resolv: Fix processing more DNSSL options than RDNSS]
  * dhcpcd: Remove option rapid_commit from dhcpcd.conf
  * privsep: Fix valgrind and hardened-malloc on Linux with SECCOMP
  * route: Don't spam route changes for lifetime
* Wed Feb 26 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.2.2
  * DHCP6: Fix dhcpcd vendor class option
  * options: Allow interface block to be pattern matching
* Mon Feb 24 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.2.1
  * Fix building with different options
  * Only drop IPv4 LL addresses if configured to handle them
* Wed Feb 12 2025 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.2.0
  * dhcp6: start request when advertise received after IRT
  * dhcpcd: stdout output sometimes empty when redirected to a file
  * Fix help text formatting
  * Apply lastlease behavior to DHCPv6
  * dhcpcd not ignoring source-based routes on linux
  * DHCP6: lastlease behavior after Confim non-response
  * Allow limited RLIMIT_FSIZE when dumping lease
  * IPv6: Avoid uninitialized ifp state when adding address
  * DHCPv6: Add support for sending Option 17 (VSIO)
  * Exit the timesyncd hook if not on systemd and not executable
  * Add route lifetime from Router Advertisement
  * revert e3c5de1
  * Fix using multiple enterprise IDs with vendclass (Option 124
    DHCP / Option 16 DHCPv6)
  * Update route if acquired time changes
  * Always send req for InfoRefreshTime option on Inform-Req
  * Increase max IPv4 clientid
  * Update build.yml to fix BSD builds
* Mon Oct  7 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.1.0
  * dhcp: get_option_uint32/16 only accept options with correct len
  * Include frame header in buffer length
* Wed Aug 21 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Update to 10.0.10
  * Option 2: Fix stdin parsing
  * IPv4LL: Restart ARP probling on address conflict
  * DHCP: Handle option 108 correctly when receiving 0.0.0.0 OFFER
  * DHCP: No longer set interface mtu
  * Update privsep-linux.c to allow statx
* Mon Jul  1 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Initial packaging @ 10.0.8
